@@ -1,3 +1,3 @@
 """Module implementing point processes and properties related to them."""
 from fpp_sle.fpp import get_arrival_times  # noqa: F401
-from fpp_sle.fpp.implementations import *  # noqa: F401, F403
+from fpp_sle.fpp.forcing_generators import *  # noqa: F401, F403
